@@ -1,5 +1,5 @@
-#ifndef __MOBIUS_CRYPT_HASH_SHA2_512_256_H__
-#define __MOBIUS_CRYPT_HASH_SHA2_512_256_H__
+#ifndef MOBIUS_CRYPT_HASH_SHA2_224_H
+#define MOBIUS_CRYPT_HASH_SHA2_224_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
@@ -25,30 +25,30 @@ namespace mobius
 namespace crypt
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief SHA-2 512/256 bits hash function implementation
+//! \brief SHA-2 224 bits hash function implementation
 //! \author Eduardo Aguiar
 //! \see http://nvlpubs.nist.gov/nistpubs/FIPS/NIST.FIPS.180-4.pdf
 //! \see https://en.wikipedia.org/wiki/SHA-2
 //! \see https://tools.ietf.org/html/rfc6234
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-class hash_sha2_512_256 : public hash_block
+class hash_sha2_224 : public hash_block
 {
 public:
-  hash_sha2_512_256 () noexcept;
+  hash_sha2_224 () noexcept;
 
 private:
   void _update_block (const mobius::bytearray&) noexcept override final;
   void _reset () noexcept override final;
-  const mobius::bytearray _evaluate (const mobius::bytearray&) override final;
+  mobius::bytearray _evaluate (const mobius::bytearray&) override final;
 
-  std::uint64_t a_;
-  std::uint64_t b_;
-  std::uint64_t c_;
-  std::uint64_t d_;
-  std::uint64_t e_;
-  std::uint64_t f_;
-  std::uint64_t g_;
-  std::uint64_t h_;
+  std::uint32_t a_;
+  std::uint32_t b_;
+  std::uint32_t c_;
+  std::uint32_t d_;
+  std::uint32_t e_;
+  std::uint32_t f_;
+  std::uint32_t g_;
+  std::uint32_t h_;
   std::uint64_t size_;
 };
 
