@@ -1,5 +1,5 @@
-#ifndef __MOBIUS_PYTHON_API_DATETIME_H__
-#define __MOBIUS_PYTHON_API_DATETIME_H__
+#ifndef MOBIUS_PYTHON_API_DATETIME_H
+#define MOBIUS_PYTHON_API_DATETIME_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
